@@ -1,4 +1,4 @@
-from .template import TEMPLATE_DIR
+from .paud import SimdakPaud
 from .version import __version__
 
 __all__ = ["SimdakPaud"]
